@@ -40,7 +40,7 @@ static gboolean zenity_general_multiple;
 static gboolean zenity_general_editable;
 static gchar   *zenity_general_uri;
 static gboolean zenity_general_dialog_no_wrap;
-static guint    zenity_general_timeout_delay;
+static gint     zenity_general_timeout_delay;
 
 /* Calendar Dialog Options */
 static gboolean zenity_calendar_active;
@@ -65,7 +65,7 @@ static gboolean       zenity_file_active;
 static gboolean       zenity_file_directory;
 static gboolean       zenity_file_save;
 static gboolean       zenity_file_confirm_overwrite;
-static GtkFileFilter *zenity_file_filter;
+static gchar        **zenity_file_filter;
 
 /* List Dialog Options */
 static gboolean zenity_list_active;
@@ -257,7 +257,7 @@ static GOptionEntry entry_options[] = {
     G_OPTION_ARG_NONE,
     &zenity_entry_hide_text,
     N_("Hide the entry text"),
-    N_("TEXT")
+    NULL
   },
   { 
     NULL 
@@ -402,6 +402,7 @@ static GOptionEntry file_selection_options[] = {
     G_OPTION_ARG_STRING_ARRAY,
     &zenity_file_filter,
     N_("Sets a filename filter"),
+    /* Help for file-filter argument (name and patterns for file selection) */
     N_("NAME | PATTERN1 PATTERN2 ..."),
   },
   { 
@@ -860,6 +861,9 @@ zenity_option_free (void) {
   if (zenity_entry_entry_text)
     g_free (zenity_entry_entry_text);
 
+  if (zenity_file_filter)
+    g_strfreev (zenity_file_filter);
+
   if (zenity_list_columns)
     g_strfreev (zenity_list_columns);
   if (zenity_list_print_column)
